@@ -7,6 +7,11 @@
 
 using namespace Rcpp;
 
+// [[Rcpp::export]]
+arma::mat pinv(arma::mat X){
+  return arma::pinv(X);
+}
+
 // [[Rcpp::export]]
 arma::mat c_variation_array(arma::mat X, bool only_variation = false){
   unsigned int K = X.n_cols;
@@ -112,12 +117,14 @@ arma::mat ilr_to_alr(unsigned int dim){
 }
 
 // [[Rcpp::export]]
-arma::mat clr_coordinates(arma::mat X){
+arma::mat clr_coordinates(arma::mat &X){
   arma::mat LOGX = log(X);
+  arma::mat m = mean(LOGX, 1);
 
-  for(unsigned int i = 0; i < X.n_rows; i++){
-    LOGX.row(i) = LOGX.row(i) - mean(LOGX.row(i));
-  }
+  LOGX.each_col() -= m;
+   // for(unsigned int i = 0; i < X.n_rows; i++){
+   //   LOGX.row(i) = LOGX.row(i) - mean(LOGX.row(i));
+   // }
 
   return(LOGX);
 }
@@ -133,20 +140,10 @@ arma::mat inv_clr_coordinates(arma::mat clrX){
 }
 
 // [[Rcpp::export]]
-arma::mat coordinates_alr2(arma::mat X, int denominator){
+arma::mat alr_coordinates(arma::mat &X, int denominator){
+  int idenom = X.n_cols-1;
+  arma::mat res(X.n_rows, idenom);
   arma::mat logX = log(X);
-  arma::mat res = logX(arma::span::all, arma::span(0,X.n_cols-2));
-  for(unsigned int i = 0; i < res.n_cols; i++){
-    res(arma::span::all, i) -= logX(arma::span::all,X.n_cols-1);
-  }
-  return(res);
-}
-
-// [[Rcpp::export]]
-arma::mat coordinates_alr(arma::mat X, int denominator){
-  arma::mat logX = log(X);
-  arma::mat res(logX.n_rows, logX.n_cols-1);
-  int idenom = logX.n_cols-1;
   for(unsigned int j = 0; j < res.n_cols; j++){
     for(unsigned int i = 0; i< res.n_rows; i++){
       res(i,j) = logX(i,j) - logX(i,idenom);
@@ -158,6 +155,11 @@ arma::mat coordinates_alr(arma::mat X, int denominator){
   return(res);
 }
 
+// [[Rcpp::export]]
+arma::mat matrix_coordinates(arma::mat X, arma::mat B){
+    return(log(X) * B);
+}
+
 // [[Rcpp::export]]
 arma::mat coordinates_basis(arma::mat X, arma::mat B, bool sparse = false){
   if(sparse){
@@ -171,7 +173,7 @@ arma::mat coordinates_basis(arma::mat X, arma::mat B, bool sparse = false){
 }
 
 // [[Rcpp::export]]
-arma::mat ilr_coordinates(arma::mat X){
+arma::mat ilr_coordinates(arma::mat &X){
   arma::mat logX = log(X);
   arma::mat B = ilr_basis_default(X.n_cols);
   return(logX * B);
